
set seed = 31.
input program.
  loop #i = 1 to 250.
    compute Gruppe = rnd(uniform(1)).
    compute Alter = rnd(30 + uniform(60)).
    compute Person = normal(0.5).
    compute Beta0i = Person + normal(0.5).
    compute Beta1i = Person + normal(0.5).
    compute Belastung1 = normal(0.3).
    compute Belastung2 = normal(0.3).
    compute Belastung3 = normal(0.3).
    compute Belastung4 = normal(0.3).
  end case.
  end loop.
end file .
end input program .
execute.

VARSTOCASES
  /ID=id
  /MAKE Belastung FROM Belastung1 Belastung2 Belastung3 Belastung4
  /INDEX=Zeit(4) 
  /KEEP=Gruppe Alter Beta0i Beta1i
  /NULL=KEEP.

compute Zeit = Zeit-1.
compute Belastung = normal(0.3).
compute LP = (0.2 + Beta0i) + Beta1i * Zeit  - 1*Gruppe*Zeit + Belastung.
compute Krank = uniform(1) <= exp(lp) / (1+exp(lp)).

VARIABLE LEVEL Zeit (scale).
formats Gruppe, Alter, Krank  (f1.0).
value labels Gruppe 0 'Kontrollgruppe' 1 'Behandlungsgruppe'.

* Ca. 10% der Beobachtungen fehlen nach dem MCAR-Prinzip.
compute #ausfall = 0.
do if (uniform(1) < 0.10).
  compute #ausfall = 1.
end if.
select if (#ausfall = 0).

* Verallgemeinerte Schtzungsgleichungen.
GENLIN Krank (REFERENCE=FIRST) WITH Gruppe Zeit Belastung Alter
  /MODEL Gruppe Zeit Belastung  Alter Gruppe*Zeit INTERCEPT=YES
 DISTRIBUTION=BINOMIAL LINK=LOGIT
  /CRITERIA METHOD=FISHER(1) SCALE=1 MAXITERATIONS=100 MAXSTEPHALVING=5 PCONVERGE=1E-006(ABSOLUTE) 
    SINGULAR=1E-012 ANALYSISTYPE=3(WALD) CILEVEL=95 LIKELIHOOD=FULL
  /REPEATED SUBJECT=id WITHINSUBJECT=Zeit SORT=YES CORRTYPE=UNSTRUCTURED ADJUSTCORR=YES 
    COVB=ROBUST MAXITERATIONS=100 PCONVERGE=1e-006(ABSOLUTE) UPDATECORR=1
  /MISSING CLASSMISSING=EXCLUDE
  /PRINT CPS DESCRIPTIVES MODELINFO FIT SUMMARY SOLUTION (EXPONENTIATED) WORKINGCORR
  /SAVE PEARSONRESID.

* Logistische Regression (ignorierte Abhngigkeit).
LOGISTIC REGRESSION VARIABLES Krank
  /METHOD=ENTER Gruppe Zeit Belastung Alter Gruppe*Zeit 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20) CUT(.5).

* Korrelationsmatrix der Pearson-Residuen zum Vergleich mit der Arbeitskorrelationsmatrix erstellen.
CASESTOVARS
  /ID=id
  /INDEX=Zeit
  /GROUPBY=VARIABLE.

CORRELATIONS
  /VARIABLES=PearsonResidual.0 PearsonResidual.1 PearsonResidual.2 PearsonResidual.3
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.

VARIABLE LEVEL krank.0 to krank.3 (scale).

* Diagrammerstellung.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=MEAN(Krank.0) MEAN(Krank.1) MEAN(Krank.2) 
    MEAN(Krank.3) Gruppe MISSING=LISTWISE REPORTMISSING=NO
    TRANSFORM=VARSTOCASES(SUMMARY="#SUMMARY" INDEX="#INDEX")
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: SUMMARY=col(source(s), name("#SUMMARY"))
  DATA: INDEX=col(source(s), name("#INDEX"), unit.category())
  DATA: Gruppe=col(source(s), name("Gruppe"), unit.category())
  GUIDE: axis(dim(1), label("Zeit"))
  GUIDE: axis(dim(2), label("Anteil"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("Gruppe"))
  SCALE: cat(dim(1), include("0", "1", "2", "3"))
  SCALE: linear(dim(2), include(0))
  SCALE: cat(aesthetic(aesthetic.color.interior), include("0", "1"))
  ELEMENT: line(position(INDEX*SUMMARY), color.interior(Gruppe), missing.wings())
  ELEMENT: point(position(INDEX*SUMMARY), color.interior(Gruppe), color.exterior(Gruppe)) 
END GPL.
