﻿* Standardfehler für Makro- und Mikroregressoren:
   a) bei ignorierter Abhängigkeit (nomalverteilte Residuen, LM)
   b) bei ignorierter Abhängigkeit (binomialverteilte Residuen, GLM)
   c) bei berücksichtigter Abhängigkeit (binomialverteilte Residuen, GEE).

* Daten generieren.
set seed = 501.
input program.
+ loop #i = 1 to 1000.
     compute #nr =$casenum - 1.
-  end case.
+ end loop.
+ end file.
end input program.

* Cluster mit 10 Fällen bilden.
compute Cluster = TRUNC(#nr/10) + 1.

compute RandomIntercept = normal(9).
compute dummy = normal(10).
compute X = normal(1).

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=Cluster
  /u0=MEAN(RandomIntercept)
  /W=MEAN(dummy).

sort cases by Cluster.

* Wahre Random-Intercept - Varianz: 10 * 81 /100 = 8,1.
FREQUENCIES VARIABLES=u0
  /FORMAT=NOTABLE
  /STATISTICS=VARIANCE MEAN
  /ORDER=ANALYSIS.

* Wahres  Modell mit normalverteilten Residuen.
compute Y = u0 + X + normal(3).
* Im Modell mit normalverteilten Residuen ergibt sich aus der Residualvarianz von 9 zusammen
  mit der Random-Intercept - Varianz von 8,1 eine wahre ICC von 0,474.

* Wahres Modell mit dichotomem Kriterium.
compute YD = (u0 + X + normal(3)) > 0.

formats Cluster YD (f1.0).
VARIABLE LEVEL Y (SCALE) Cluster YD (NOMINAL).
EXECUTE.


********************************************************************
* Analysen für das Kriterium mit normalverteilten Residuen
*********************************************************************

* LM.
REGRESSION
  /DEPENDENT Y
  /METHOD=ENTER X W.

* GEE mit normalverteilten Residuen.
GENLIN Y (REFERENCE=FIRST) WITH X W
  /MODEL X W INTERCEPT=YES
 DISTRIBUTION=NORMAL LINK=IDENTITY
  /CRITERIA METHOD=FISHER(1) SCALE=1 MAXITERATIONS=100 MAXSTEPHALVING=5 PCONVERGE=1E-006(ABSOLUTE) 
    SINGULAR=1E-012 ANALYSISTYPE=3(WALD) CILEVEL=95 LIKELIHOOD=FULL
  /REPEATED SUBJECT=Cluster SORT=YES CORRTYPE=EXCHANGEABLE ADJUSTCORR=YES COVB=ROBUST 
    MAXITERATIONS=100 PCONVERGE=1e-006(ABSOLUTE) UPDATECORR=1
  /MISSING CLASSMISSING=EXCLUDE
  /PRINT CPS DESCRIPTIVES MODELINFO FIT SUMMARY SOLUTION WORKINGCORR.

* LMM mit normalverteilten Residuen.
MIXED Y WITH X W
  /CRITERIA=CIN(95) MXITER(100) MXSTEP(10) SCORING(1) SINGULAR(0.000000000001) HCONVERGE(0, 
    ABSOLUTE) LCONVERGE(0, ABSOLUTE) PCONVERGE(0.000001, ABSOLUTE)
  /FIXED=X W | SSTYPE(3)
  /METHOD=REML
  /PRINT=SOLUTION TESTCOV
  /RANDOM=INTERCEPT | SUBJECT(Cluster) COVTYPE(VC).


*********************************************************************
* Analysen für das Kriterium mit binomialverteilten Residuen
*********************************************************************

* GLM (LOGISTIC REGRESSION).
LOGISTIC REGRESSION VARIABLES YD
  /METHOD=ENTER X W 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20) CUT(.5).

* GLM (GENLIN).
GENLIN YD (REFERENCE=FIRST) WITH X W
  /MODEL X W INTERCEPT=YES
 DISTRIBUTION=BINOMIAL LINK=LOGIT
  /CRITERIA METHOD=FISHER(1) SCALE=1 COVB=ROBUST MAXITERATIONS=100 MAXSTEPHALVING=5 
    PCONVERGE=1E-006(ABSOLUTE) SINGULAR=1E-012 ANALYSISTYPE=3(LR) CILEVEL=95 CITYPE=PROFILE(.0001) 
    LIKELIHOOD=FULL
  /MISSING CLASSMISSING=EXCLUDE
  /PRINT CPS DESCRIPTIVES MODELINFO FIT SUMMARY SOLUTION.

* GEE (Arbeitskorrelationsmatrix austauschbar).
GENLIN YD (REFERENCE=FIRST) WITH X W
  /MODEL X W INTERCEPT=YES
 DISTRIBUTION=BINOMIAL LINK=LOGIT
  /CRITERIA METHOD=FISHER(1) SCALE=1 MAXITERATIONS=100 MAXSTEPHALVING=5 PCONVERGE=1E-006(ABSOLUTE) 
    SINGULAR=1E-012 ANALYSISTYPE=3(WALD) CILEVEL=95 LIKELIHOOD=FULL
  /REPEATED SUBJECT=Cluster SORT=YES CORRTYPE=EXCHANGEABLE ADJUSTCORR=YES COVB=ROBUST 
    MAXITERATIONS=100 PCONVERGE=1e-006(ABSOLUTE) UPDATECORR=1
  /MISSING CLASSMISSING=EXCLUDE
  /PRINT CPS DESCRIPTIVES MODELINFO FIT SUMMARY SOLUTION WORKINGCORR.

* GEE (Arbeitskorrelationsmatrix unabhängig).
GENLIN YD (REFERENCE=FIRST) WITH X W
  /MODEL X W INTERCEPT=YES
 DISTRIBUTION=BINOMIAL LINK=LOGIT
  /CRITERIA METHOD=FISHER(1) SCALE=1 MAXITERATIONS=100 MAXSTEPHALVING=5 PCONVERGE=1E-006(ABSOLUTE) 
    SINGULAR=1E-012 ANALYSISTYPE=3(WALD) CILEVEL=95 LIKELIHOOD=FULL
  /REPEATED SUBJECT=Cluster SORT=YES CORRTYPE=INDEPENDENT ADJUSTCORR=YES COVB=ROBUST MAXITERATIONS=100 
    PCONVERGE=1e-006(ABSOLUTE) UPDATECORR=1
  /MISSING CLASSMISSING=EXCLUDE
  /PRINT CPS DESCRIPTIVES MODELINFO FIT SUMMARY SOLUTION WORKINGCORR.
